pub(crate) mod add_vertex_index;
pub(crate) mod get_internal_vertex;
pub(crate) mod get_internal_vertices;
pub(crate) mod get_vertex;
pub(crate) mod get_vertices;

pub mod add_vertex;
pub mod count_vertices;
pub mod get_adjacent_vertices_from;
pub mod get_adjacent_vertices_to;
pub mod get_dijkstra_connections;
pub mod get_full_adjacent_vertices_from;
pub mod get_full_adjacent_vertices_to;
pub mod get_full_vertex_hyperedges;
pub mod get_vertex_degree_in;
pub mod get_vertex_degree_out;
pub mod get_vertex_hyperedges;
pub mod get_vertex_weight;
pub mod remove_vertex;
pub mod update_vertex_weight;
